This module is based on [Readme-AI](https://github.com/eli64s/readme-ai)

ReadmeAI is a developer tool that automatically generates README files using a robust repository processing engine and advanced language models.

This project includes ReadmeAI components, distributed under the MIT License.
The full text of the license can be found in the file [LICENSE](https://github.com/ITMO-NSS-team/Open-Source-Advisor/tree/main/osa_tool/LICENSE).